@@ -89,6 +89,21 @@ class EndpointMetaClass(type):
                                 for field in value.serializer().fields.keys()
                             ]
 
+        if getattr(new_class, 'fieldset_name', None) is not None:
+            fieldsets_path = os.path.join(
+                django_settings.BASE_DIR,
+                new_class.__module__.rsplit('.', 1)[0],
+                'fieldsets.json'
+            )
+            try:
+                with open(fieldsets_path, 'r') as f:
+                    fieldsets = json.load(f)
+                    new_class.fieldsets = fieldsets[new_class.fieldset_name]
+            except FileNotFoundError:
+                pass
+            except KeyError:
+                pass
+
         if new_class.fieldsets is None and new_class.model is not None:
             fieldsets_path = os.path.join(
                 django_settings.BASE_DIR,
@@ -98,10 +113,7 @@ class EndpointMetaClass(type):
             try:
                 with open(fieldsets_path, 'r') as f:
                     fieldsets = json.load(f)
-                    if hasattr(new_class, 'fieldset_name'):
-                        new_class.fieldsets = fieldsets[new_class.fieldset_name]
-                    else:
-                        new_class.fieldsets = fieldsets[new_class.model.__name__]
+                    new_class.fieldsets = fieldsets[new_class.model.__name__]
             except FileNotFoundError:
                 pass
             except KeyError:
